LocalizationApi class abstract

Provides an interface for localization operations.

This abstract class defines the contract for a localization API, including methods to retrieve localization delegates and translate strings.

Constructors

LocalizationApi()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getDelegates(List<Locale> locales, {Locale? defaultLocale, String? path}) List<LocalizationsDelegate>
Returns a list of localization delegates for the specified locales.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
translate(BuildContext context, String key, {Map<String, String>? args}) String
Translates a given localization key into the current locale's string.

Operators

operator ==(Object other) bool
The equality operator.
inherited